@@ -1,12 +1,10 @@
-import warnings
 from typing import Dict, Optional, TYPE_CHECKING, Tuple, Type
 
 import pydantic
 from pydantic.fields import ModelField
 from pydantic.utils import lenient_issubclass
 
-import ormar  # noqa: I100, I202
-from ormar.fields import BaseField
+from ormar.fields import BaseField  # noqa: I100, I202
 
 if TYPE_CHECKING:  # pragma no cover
     from ormar import Model
@@ -14,7 +12,7 @@ if TYPE_CHECKING:  # pragma no cover
 
 
 def create_pydantic_field(
-    field_name: str, model: Type["Model"], model_field: Type["ManyToManyField"]
+    field_name: str, model: Type["Model"], model_field: "ManyToManyField"
 ) -> None:
     """
     Registers pydantic field on through model that leads to passed model
@@ -59,38 +57,6 @@ def get_pydantic_field(field_name: str, model: Type["Model"]) -> "ModelField":
     )
 
 
-def populate_default_pydantic_field_value(
-    ormar_field: Type["BaseField"], field_name: str, attrs: dict
-) -> dict:
-    """
-    Grabs current value of the ormar Field in class namespace
-    (so the default_value declared on ormar model if set)
-    and converts it to pydantic.FieldInfo
-    that pydantic is able to extract later.
-
-    On FieldInfo there are saved all needed params like max_length of the string
-    and other constraints that pydantic can use to build
-    it's own field validation used by ormar.
-
-    :param ormar_field: field to convert
-    :type ormar_field: ormar Field
-    :param field_name: field to convert name
-    :type field_name: str
-    :param attrs: current class namespace
-    :type attrs: Dict
-    :return: updated namespace dict
-    :rtype: Dict
-    """
-    curr_def_value = attrs.get(field_name, ormar.Undefined)
-    if lenient_issubclass(curr_def_value, ormar.fields.BaseField):
-        curr_def_value = ormar.Undefined
-    if curr_def_value is None:
-        attrs[field_name] = ormar_field.convert_to_pydantic_field_info(allow_null=True)
-    else:
-        attrs[field_name] = ormar_field.convert_to_pydantic_field_info()
-    return attrs
-
-
 def populate_pydantic_default_values(attrs: Dict) -> Tuple[Dict, Dict]:
     """
     Extracts ormar fields from annotations (deprecated) and from namespace
@@ -110,22 +76,11 @@ def populate_pydantic_default_values(attrs: Dict) -> Tuple[Dict, Dict]:
     :rtype: Tuple[Dict, Dict]
     """
     model_fields = {}
-    potential_fields = {
-        k: v
-        for k, v in attrs["__annotations__"].items()
-        if lenient_issubclass(v, BaseField)
-    }
-    if potential_fields:
-        warnings.warn(
-            "Using ormar.Fields as type Model annotation has been deprecated,"
-            " check documentation of current version",
-            DeprecationWarning,
-        )
+    potential_fields = {}
 
     potential_fields.update(get_potential_fields(attrs))
     for field_name, field in potential_fields.items():
         field.name = field_name
-        attrs = populate_default_pydantic_field_value(field, field_name, attrs)
         model_fields[field_name] = field
         attrs["__annotations__"][field_name] = (
             field.__type__ if not field.nullable else Optional[field.__type__]
@@ -156,4 +111,8 @@ def get_potential_fields(attrs: Dict) -> Dict:
     :return: extracted fields that are ormar Fields
     :rtype: Dict
     """
-    return {k: v for k, v in attrs.items() if lenient_issubclass(v, BaseField)}
+    return {
+        k: v
+        for k, v in attrs.items()
+        if (lenient_issubclass(v, BaseField) or isinstance(v, BaseField))
+    }
